@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010  Sakari Hyoty
+  Copyright (C) 2010, 2011  Sakari Hyoty
 
   This file is part of Pomodoro.
 
@@ -22,11 +22,13 @@
 
 #include <QMainWindow>
 #include <QModelIndex>
+#include <QString>
 #include <phonon/MediaObject>
 
 class PomodoroModel;
 class PomodoroTimer;
 class TaskDialog;
+class SoundDialog;
 class QItemSelection;
 
 namespace Ui {
@@ -43,12 +45,14 @@ public:
 
 public slots:
     void addTask(QString taskName, int estimate);
+    void editTask(const QModelIndex &index);
     void removeTask();
     void completeTask();
     void internalInterruption();
     void externalInterruption();
 
     void taskSelected(const QItemSelection & selected, const QItemSelection & deselected );
+    void taskUpdated(const QModelIndex &index, QString taskName, int estimate);
 
     void pomodoroStarted(int lengthInSeconds);
     void pomodoroStopped(bool finished);
@@ -56,6 +60,11 @@ public slots:
 
     void showGuide();
     void showAbout();
+    void removeCompletedTasks();
+    void showChangeAlarmFile();
+
+    void alarmFileChanged(QString newAudioFilePath);
+    void alarmFileReset();
 
 protected:
     void changeEvent(QEvent *e);
@@ -78,6 +87,8 @@ private:
     Phonon::MediaObject *alertMediaObject;
     PomodoroTimer *pomodoroTimer;
     TaskDialog *taskDialog;
+    SoundDialog *soundDialog;
+    QString alarmFile;
 };
 
 #endif // MAINWINDOW_H
