@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010  Sakari Hyoty
+  Copyright (C) 2010, 2011  Sakari Hyoty
 
   This file is part of Pomodoro.
 
@@ -24,9 +24,11 @@
 
 const QString POMODORO_FILE_ALERT = "/opt/pomodoro/alarm.wav";
 const QString POMODORO_FILE_MODEL = QDir::homePath() + '/' + ".pomodoro.data";
-const QString POMODORO_VERSION = "0.2.1";
+const QString POMODORO_VERSION = "0.3.0";
 const QString POMODORO_HOMEPAGE = "http://www.iki.fi/shyoty/pomodoro/";
+const QString POMODORO_FILE_SETTINGS = QDir::homePath() + '/' + ".pomodoro.settings";
 
+const QString POMODORO_SETTINGS_KEY_ALARM = "alarm_file";
 const int POMODORO_TIMER_LENGTH = 25 * 60; // seconds
 const int POMODORO_TIMER_ALMOST_FINISHED = POMODORO_TIMER_LENGTH / 2; // seconds
 const int POMODORO_MODEL_VERSION = 1;
